! *****************************************************************
!
! This file contains the Fortran 90 program that runs the numerical 
! model, and compares numerical results with the analytic solution
!
! Copyright (C) 2010 David McInerney, University of Chicago
!
! *****************************************************************
!
!    This program is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    any later version.
!
!    This program is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with this program (see file "COPYING").  If not, see
!    <http://www.gnu.org/licenses/>.
!
! *****************************************************************

program main
  
! *****************************************************************

  use analytic, only : setup_analytic
  use check_module, only : check
  use numerical, only : setup_numerical, run_numerical, advection_on
  use parameters, only : print_parameters, h0, Cl
  use output_module, only : dirname
  use grid, only : JJ, KK, NN 

  implicit none

  integer test_num

  test_num = 3
  advection_on = .true.

! *********************
! Test 1

  if (test_num == 1) then

    h0 = 1d0 ! depth of lake
    Cl = 0.00075d0 ! linear fric coeff

    if ( (JJ == 28) .and. (KK == 20) .and. (NN == 2000) ) then
      if (advection_on) then
        dirname = "../Output/Manuscript/Test1/28_20_2000"
      else
        dirname = "../Output/Manuscript/Test1_adv_off/28_20_2000"
      end if

    else if ( (JJ == 56) .and. (KK == 40) .and. (NN == 8000) ) then
      if (advection_on) then
        dirname = "../Output/Manuscript/Test1/56_40_8000"
      else
        dirname = "../Output/Manuscript/Test1_adv_off/56_40_8000"
      end if

    else if ( (JJ == 140) .and. (KK == 100) .and. (NN == 50000) ) then
      if (advection_on) then
        dirname = "../Output/Manuscript/Test1/140_100_50000"
      else
        dirname = "../Output/Manuscript/Test1_adv_off/140_100_50000"
      end if  
  
    end if
 
! *********************
! Test 2

  else if (test_num == 2) then
    
    h0 = 2d0 ! depth of lake
    Cl = 0.00046d0 ! linear fric coeff

    if ( (JJ == 28) .and. (KK == 20) .and. (NN == 2000) ) then
      if (advection_on) then
        dirname = "../Output/Manuscript/Test2/28_20_2000"
      else
        dirname = "../Output/Manuscript/Test2_adv_off/28_20_2000"
      end if

    else if ( (JJ == 56) .and. (KK == 40) .and. (NN == 8000) ) then
      if (advection_on) then
        dirname = "../Output/Manuscript/Test2/56_40_8000"
      else 
        dirname = "../Output/Manuscript/Test2_adv_off/56_40_8000"      
      end if

    else if ( (JJ == 140) .and. (KK == 100) .and. (NN == 50000) ) then
      if (advection_on) then
        dirname = "../Output/Manuscript/Test2/140_100_50000"
      else
        dirname = "../Output/Manuscript/Test2_adv_off/140_100_50000"
      end if

    end if

! *********************
! Test 3

  else if (test_num == 3) then

    h0 = 5d0 ! depth of lake
    Cl = 0.000145d0 ! linear fric coeff

    if ( (JJ == 28) .and. (KK == 20) .and. (NN == 2000) ) then
      if (advection_on) then
        dirname = "../Output/Manuscript/Test3/28_20_2000"
      else
        dirname = "../Output/Manuscript/Test3_adv_off/28_20_2000"
      end if

    else if ( (JJ == 56) .and. (KK == 40) .and. (NN == 8000) ) then
      if (advection_on) then
        dirname = "../Output/Manuscript/Test3/56_40_8000"
      else
        dirname = "../Output/Manuscript/Test3_adv_off/56_40_8000"
      end if

    else if ( (JJ == 140) .and. (KK == 100) .and. (NN == 50000) ) then
      if (advection_on) then
        dirname = "../Output/Manuscript/Test3/140_100_50000"
      else
        dirname = "../Output/Manuscript/Test3_adv_off/140_100_50000"
      end if

    end if

  end if

! *********************

  print*,"Test ", test_num
  print*,"Advection_on = ", advection_on
  print*,"Output directory = ",dirname

! print parameters
  call print_parameters

! setup numerical solution
  call setup_numerical

! setup analytic solution
  call setup_analytic

! check to see if assumptions are satisfied
!  call check
!   stop

  call run_numerical

end program main

