! *****************************************************************
!
! This file contains a Fortran 90 module for specifying and printing 
! parameters
!
! Copyright (C) 2010 David McInerney, University of Chicago
!
! *****************************************************************
!
!    This program is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    any later version.
!
!    This program is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with this program (see file "COPYING").  If not, see
!    <http://www.gnu.org/licenses/>.
!
! *****************************************************************

module parameters

! *****************************************************************

  double precision :: g = 9.81d0 ! gravity
  double precision :: rho = 1000d0 ! density of water
  double precision :: tau_0 = 0.5d0 ! max wind stress
  double precision :: period = 3d0*3600d0 ! period of wind cycle
  double precision :: angle = 45d0 ! angle of wind direction
  double precision :: LL = 14000d0 ! length of lake
  double precision :: BB = 10000d0 ! breadth of lake

 integer :: no_warmups = 1000 ! number of warmup periods for numerical model
! integer :: no_warmups = 20 ! number of warmup periods for numerical model

  double precision ::   h0
  double precision ::   Cl

  double precision sigma, alpha
  double precision ::   Cb = 0.0025d0 ! quadratic fric coeff

contains

! *****************************************************************
  
  subroutine print_parameters

    implicit none

    print*
    print*,"g =",g
    print*,"rho =",rho
    print*,"tau_0 =",tau_0
    print*,"T =",period
    print*,"angle =",angle
    print*,"L =",LL
    print*,"B =",BB
    print*,"h0 =",h0
    print*,"Cl =",Cl
    print*,"# warmup periods =",no_warmups
    
  end subroutine print_parameters

end module parameters
